@@ -1,6 +1,6 @@
 /*
     Video maid
-    copyright (c) 1998-2002 Iwamoto,Kazuki http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -21,11 +21,11 @@
 #include "file.h"
 #include "general.h"
 #include "jump.h"
-#include "other.h"
 #include "prop.h"
 #include "save.h"
 #include "size.h"
 #include "thread.h"
+#include "misc/misc.h"
 
 
 /******************************************************************************
@@ -38,7 +38,7 @@ void command_new(gpointer callback_data,guint callback_action,
 {
 	pthread_t id;
 
-	pthread_create(&id,NULL,(void *)open_edit_file,NULL);
+	pthread_create(&id,NULL,(void *)file_open_edit,NULL);
 	pthread_detach(id);
 }
 
@@ -63,7 +63,7 @@ void command_open(gpointer callback_data,guint callback_action,
 															GtkWidget *widget)
 {
 	pthread_t id;
-	OpenFile *open_file;
+	FileOpen *file_open;
 
 	command_open_file=NULL;
 	command_open_dialog=gtk_file_selection_new(_("Open"));
@@ -90,12 +90,12 @@ void command_open(gpointer callback_data,guint callback_action,
 	gtk_main();
 	if (command_open_file!=NULL) {
 		g_free(open_path);
-		open_path=get_full_path(command_open_file);
+		open_path=misc_get_full_path(command_open_file);
 		*g_basename(open_path)='\0';
-		open_file=g_malloc(sizeof(OpenFile));
-		open_file->file=command_open_file;
-		open_file->merge=file_merge=command_open_merge;
-		pthread_create(&id,NULL,(void *)open_edit_file,open_file);
+		file_open=g_malloc(sizeof(FileOpen));
+		file_open->file=command_open_file;
+		file_open->merge=file_merge=command_open_merge;
+		pthread_create(&id,NULL,(void *)file_open_edit,file_open);
 		pthread_detach(id);
 	}
 }
@@ -105,7 +105,7 @@ void command_save(gpointer callback_data,guint callback_action,
 															GtkWidget *widget)
 {
 	pthread_t id;
-	SaveFile *save_file;
+	FileSave *file_save;
 	VmaidWindow *vmaid;
 
 	vmaid=gtk_object_get_user_data(GTK_OBJECT(
@@ -130,30 +130,30 @@ void command_save(gpointer callback_data,guint callback_action,
 	gtk_main();
 	if (command_open_file!=NULL) {
 		g_free(save_path);
-		save_path=get_full_path(command_open_file);
+		save_path=misc_get_full_path(command_open_file);
 		*g_basename(save_path)='\0';
-		save_file=g_malloc(sizeof(SaveFile));
-		save_file->file=command_open_file;
+		file_save=g_malloc(sizeof(FileSave));
+		file_save->file=command_open_file;
 		if (vmaid->avi[0]!=NULL) {
-			save_file->max=avi_length(vmaid->avi[0])-1;
+			file_save->max=avi_length(vmaid->avi[0])-1;
 			if (vmaid->select.stream>=0) {
-				save_file->start=MIN(vmaid->cursor.frame,vmaid->select.frame);
-				save_file->end=MIN(MAX(vmaid->cursor.frame,
-										vmaid->select.frame)-1,save_file->max);
-				if (save_file->start>save_file->end) {
-					save_file->start=0;
-					save_file->end=save_file->max;
+				file_save->start=MIN(vmaid->cursor.frame,vmaid->select.frame);
+				file_save->end=MIN(MAX(vmaid->cursor.frame,
+										vmaid->select.frame)-1,file_save->max);
+				if (file_save->start>file_save->end) {
+					file_save->start=0;
+					file_save->end=file_save->max;
 				}
 			} else {
-				save_file->start=save_file->end
-									=MIN(vmaid->cursor.frame,save_file->max);
+				file_save->start=file_save->end
+									=MIN(vmaid->cursor.frame,file_save->max);
 			}
-			save_file->avi[0]=avi_clone(vmaid->avi[0]);
+			file_save->avi[0]=avi_clone(vmaid->avi[0]);
 		}
-		save_file->avi[1]=vmaid->avi[1]!=NULL?avi_clone(vmaid->avi[1]):NULL;
-		if (save_dialog(save_file)) {
+		file_save->avi[1]=vmaid->avi[1]!=NULL?avi_clone(vmaid->avi[1]):NULL;
+		if (save_dialog(file_save)) {
 			/*  */
-			if (save_file->mode==0 || save_file->mode==3) {
+			if (file_save->mode==0 || file_save->mode==3) {
 				vmaid->edit=FALSE;
 				g_free(vmaid->file);
 				vmaid->file=g_strdup(command_open_file);
@@ -161,16 +161,16 @@ void command_save(gpointer callback_data,guint callback_action,
 				delete_list(&vmaid->redo);
 				set_menu_bar(vmaid);
 			}
-			if (save_file->mode!=2 || save_file->start==save_file->end)
-				set_history(command_open_file);
+			if (file_save->mode!=2 || file_save->start==file_save->end)
+				file_set_history(command_open_file);
 			/* ¸ */
-			pthread_create(&id,NULL,(void *)save_edit_file,save_file);
+			pthread_create(&id,NULL,(void *)file_save_edit,file_save);
 			pthread_detach(id);
 		} else {
-			if (save_file->avi[0]!=NULL)
-				avi_release(save_file->avi[0]);
-			if (save_file->avi[1]!=NULL)
-				avi_release(save_file->avi[1]);
+			if (file_save->avi[0]!=NULL)
+				avi_release(file_save->avi[0]);
+			if (file_save->avi[1]!=NULL)
+				avi_release(file_save->avi[1]);
 			g_free(command_open_file);
 		}
 	}
@@ -369,7 +369,7 @@ void command_delete(gpointer callback_data,guint callback_action,
 			result=FALSE;
 	}
 	if (!result) {
-		message_box("Video maid",_("AVI Clone Error"),0,_("OK"),NULL);
+		misc_message_box("Video maid",_("AVI Clone Error"),0,_("OK"),NULL);
 		for (i=0;i<2;i++)
 			if (d->avi[i]!=NULL)
 				avi_release(d->avi[i]);
@@ -413,7 +413,7 @@ void command_delete(gpointer callback_data,guint callback_action,
 		}
 	}
 	if (!result) {
-		message_box("Video maid",_("AVI Delete Error"),0,_("OK"),NULL);
+		misc_message_box("Video maid",_("AVI Delete Error"),0,_("OK"),NULL);
 		for (i=0;i<2;i++) {
 			if (vmaid->avi[i]!=NULL)
 				avi_release(vmaid->avi[i]);
@@ -440,12 +440,12 @@ void command_delete(gpointer callback_data,guint callback_action,
 		vmaid->top=MAX(vmaid->cursor.frame-sx,0);
 	/* ˥塼,ơȥ,ҥɥ */
 	set_menu_bar(vmaid);
-	gtk_widget_set_usize(vmaid->drawing,vmaid->width*3+4,system_fontheight*2
+	gtk_widget_set_usize(vmaid->drawing,vmaid->width*3+4,system_font_height*2
 		+((vmaid->avi[0]!=NULL?1:0)+(vmaid->avi[1]!=NULL?1:0))*vmaid->height);
 	gtk_container_queue_resize(GTK_CONTAINER(window));
 	gtk_widget_draw(vmaid->drawing,NULL);
 	draw_caret(vmaid,NULL);
-	set_scroll_bar(vmaid->hscroll,signal_value_changed_hscroll,vmaid,
+	misc_set_scroll_bar(vmaid->hscroll,signal_value_changed_hscroll,vmaid,
 														0,max,sx,vmaid->top);
 	vmaid->edit=TRUE;
 }
@@ -483,8 +483,8 @@ void command_jump(gpointer callback_data,guint callback_action,
 			set_menu_bar(vmaid);
 		}
 		if (vmaid->top!=top)
-			set_scroll_bar(vmaid->hscroll,signal_value_changed_hscroll,vmaid,
-													0,jump.max,sx,vmaid->top);
+			misc_set_scroll_bar(vmaid->hscroll,signal_value_changed_hscroll,
+											vmaid,0,jump.max,sx,vmaid->top);
 		clear_sel(vmaid,&cursor,&select,top);
 		draw_caret(vmaid,&cursor);
 	}
@@ -519,8 +519,8 @@ void command_all(gpointer callback_data,guint callback_action,
 		if (select.stream<0)
 			set_menu_bar(vmaid);
 		if (vmaid->top!=top)
-			set_scroll_bar(vmaid->hscroll,signal_value_changed_hscroll,vmaid,
-														0,max,sx,vmaid->top);
+			misc_set_scroll_bar(vmaid->hscroll,signal_value_changed_hscroll,
+													vmaid,0,max,sx,vmaid->top);
 		clear_sel(vmaid,&cursor,&select,top);
 		draw_caret(vmaid,&cursor);
 	}
@@ -553,7 +553,7 @@ void command_size(gpointer callback_data,guint callback_action,
 		vmaid->width=size.width;
 		vmaid->height=size.height;
 		gtk_widget_set_usize(vmaid->drawing,vmaid->width*3+4,
-								system_fontheight*2+((vmaid->avi[0]!=NULL?1:0)
+								system_font_height*2+((vmaid->avi[0]!=NULL?1:0)
 									+(vmaid->avi[1]!=NULL?1:0))*vmaid->height);
 		gtk_container_queue_resize(GTK_CONTAINER(window));
 		gtk_widget_draw(vmaid->drawing,NULL);
