@@ -1,6 +1,6 @@
 /*
     Video maid
-    copyright (c) 1998-2002 Iwamoto,Kazuki http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,12 +20,12 @@
 #include <sys/file.h>
 #include <sys/stat.h>
 #include <unistd.h>
-#include "avicore.h"
 #include "file.h"
-#include "other.h"
 #include "signal.h"
 #include "size.h"
 #include "thread.h"
+#include "avicore/avicore.h"
+#include "misc/misc.h"
 
 
 /******************************************************************************
@@ -35,7 +35,7 @@
 ******************************************************************************/
 /*	ե˲ä
 	file,ե̾															*/
-void set_history(gchar *file)
+void file_set_history(const gchar *file)
 {
 	gchar *label;
 	gint i,count;
@@ -81,7 +81,7 @@ void set_history(gchar *file)
 	file,ä褦ȤեΥեѥ
 	same,եѥ°
 	 RET,ä褦ȤեΥ٥										*/
-gchar *add_edit_file(gchar *file,gint *same)
+gchar *file_add_edit(const gchar *file,gint *same)
 {
 	gchar *label,*name0,*name1;
 	gint i;
@@ -133,7 +133,7 @@ gchar *add_edit_file(gchar *file,gint *same)
 
 /*	ե
 	file,褦ȤեΥեѥ									*/
-void delete_edit_file(gchar *file)
+void file_delete_edit(const gchar *file)
 {
 	gchar *name0,*name1;
 	gint i,count=0;
@@ -189,7 +189,7 @@ void delete_edit_file(gchar *file)
 /*	AVIե򳫤
 	 avi,AVIԽ¤
 	file,ե̾															*/
-static void open_avi_file(AviEdit *avi[],gchar *file)
+static void file_open_avi(AviEdit *avi[],const gchar *file)
 {
 	gint i;
 	guint32 streams;
@@ -219,9 +219,9 @@ static void open_avi_file(AviEdit *avi[],gchar *file)
 
 
 /*	ե򳫤(Ωå)
-	open_file,Open
+	file_open,Open
 	 RET,ɥ														*/
-VmaidWindow *open_edit_file(OpenFile *open_file)
+VmaidWindow *file_open_edit(FileOpen *file_open)
 {
 	int fd;
 	gboolean result;
@@ -248,7 +248,7 @@ VmaidWindow *open_edit_file(OpenFile *open_file)
 "..    .."};
 
 	id=pthread_self();
-	thread_insert(id,1,open_file!=NULL?open_file->file:NULL);
+	thread_insert(id,1,file_open!=NULL?file_open->file:NULL);
 
 	vmaid=g_malloc(sizeof(VmaidWindow));
 	vmaid->edit=FALSE;
@@ -264,14 +264,14 @@ VmaidWindow *open_edit_file(OpenFile *open_file)
 	vmaid->avi[0]=NULL;
 	vmaid->avi[1]=NULL;
 	vmaid->timer_id=0;
-	if (open_file==NULL) {
+	if (file_open==NULL) {
 		/*  */
 		vmaid->file=g_strdup_printf("new%04d",fcount++%1000);
 	} else {
-		vmaid->file=get_full_path(open_file->file);
-		g_free(open_file->file);
-		open_avi_file(vmaid->avi,vmaid->file);
-		if ((vmaid->avi[0]!=NULL || vmaid->avi[1]!=NULL) && open_file->merge) {
+		vmaid->file=misc_get_full_path(file_open->file);
+		g_free(file_open->file);
+		file_open_avi(vmaid->avi,vmaid->file);
+		if ((vmaid->avi[0]!=NULL || vmaid->avi[1]!=NULL) && file_open->merge) {
 			/* Ϣ */
 			name=g_basename(vmaid->file);
 			for (i=strlen(name)-1;i>=0;i--)
@@ -284,7 +284,7 @@ VmaidWindow *open_edit_file(OpenFile *open_file)
 				for (j=i-1;j>=0;j--)
 					if (head[j]<'0' || '9'<head[j])
 						break;
-				strval(&value,head+j+1,10,FALSE);
+				misc_str_to_val(&value,head+j+1,10,FALSE);
 				head[j+1]='\0';
 				format=g_strdup_printf("%s/%s%%0%dd%s",dir,head,i-j,foot);
 				g_free(dir);
@@ -300,7 +300,7 @@ VmaidWindow *open_edit_file(OpenFile *open_file)
 			result=TRUE;
 			for (i=value-1;i>=0;i--) {
 				file=g_strdup_printf(format,i);
-				open_avi_file(avi,file);
+				file_open_avi(avi,file);
 				g_free(file);
 				if (avi[0]==NULL && avi[1]==NULL)
 					break;
@@ -328,7 +328,7 @@ VmaidWindow *open_edit_file(OpenFile *open_file)
 			result=TRUE;
 			for (i=value+1;i<max;i++) {
 				file=g_strdup_printf(format,i);
-				open_avi_file(avi,file);
+				file_open_avi(avi,file);
 				g_free(file);
 				if (avi[0]==NULL && avi[1]==NULL)
 					break;
@@ -359,7 +359,7 @@ VmaidWindow *open_edit_file(OpenFile *open_file)
 											&& avi_file_type(vmaid->file)==3) {
 			/* ե򳫤 */
 			if ((fd=open(vmaid->file,O_RDONLY))==-1) {
-				g_free(open_file);
+				g_free(file_open);
 				g_free(vmaid->file);
 				g_free(vmaid);
 				return NULL;
@@ -369,7 +369,7 @@ VmaidWindow *open_edit_file(OpenFile *open_file)
 									|| lseek(fd,0,SEEK_SET)==-1
 									|| (scenario=g_malloc(offset+1))==NULL) {
 				close(fd);
-				g_free(open_file);
+				g_free(file_open);
 				g_free(vmaid->file);
 				g_free(vmaid);
 				return 0;
@@ -378,14 +378,14 @@ VmaidWindow *open_edit_file(OpenFile *open_file)
 			if (read(fd,scenario,offset)!=offset) {
 				close(fd);
 				g_free(scenario);
-				g_free(open_file);
+				g_free(file_open);
 				g_free(vmaid->file);
 				g_free(vmaid);
 				return 0;
 			}
 			if (close(fd)!=0) {
 				g_free(scenario);
-				g_free(open_file);
+				g_free(file_open);
 				g_free(vmaid->file);
 				g_free(vmaid);
 				return 0;
@@ -412,7 +412,7 @@ VmaidWindow *open_edit_file(OpenFile *open_file)
 	}
 
 	if (!thread_idling(id,100)) {
-		g_free(open_file);
+		g_free(file_open);
 		g_free(vmaid->file);
 		for (i=0;i<2;i++)
 			if (vmaid->avi[i]!=NULL)
@@ -422,12 +422,12 @@ VmaidWindow *open_edit_file(OpenFile *open_file)
 	}
 
 	if (vmaid->avi[0]!=NULL) {
-		set_scale(default_view,&vmaid->width,&vmaid->height,
+		size_set_scale(default_view,&vmaid->width,&vmaid->height,
 				avi_get_width(vmaid->avi[0]),avi_get_height(vmaid->avi[0]));
 		vmaid->rate=avi_rate(vmaid->avi[0]);
 		vmaid->scale=avi_scale(vmaid->avi[0]);
 	} else {
-		set_scale(default_view,&vmaid->width,&vmaid->height,-1,-1);
+		size_set_scale(default_view,&vmaid->width,&vmaid->height,-1,-1);
 	}
 	if (vmaid->avi[0]==NULL && vmaid->avi[1]!=NULL)
 		vmaid->cursor.stream=1;
@@ -435,7 +435,7 @@ VmaidWindow *open_edit_file(OpenFile *open_file)
 	gdk_threads_enter();
 
 	/* ե̾Ĵ٤ */
-	text=add_edit_file(vmaid->file,&vmaid->same);
+	text=file_add_edit(vmaid->file,&vmaid->same);
 
 	/* ɽꥢ */
 	vmaid->drawing=gtk_drawing_area_new();
@@ -462,7 +462,7 @@ VmaidWindow *open_edit_file(OpenFile *open_file)
 	gtk_widget_add_events(vmaid->drawing,GDK_FOCUS_CHANGE
 						| GDK_BUTTON_PRESS_MASK | GDK_POINTER_MOTION_MASK
 						| GDK_POINTER_MOTION_HINT_MASK | GDK_BUTTON_RELEASE);
-	gtk_widget_set_usize(vmaid->drawing,vmaid->width*3+4,system_fontheight*2
+	gtk_widget_set_usize(vmaid->drawing,vmaid->width*3+4,system_font_height*2
 		+((vmaid->avi[0]!=NULL?1:0)+(vmaid->avi[1]!=NULL?1:0))*vmaid->height);
 	GTK_WIDGET_SET_FLAGS(vmaid->drawing,GTK_CAN_FOCUS);
 	/* С */
@@ -505,12 +505,12 @@ VmaidWindow *open_edit_file(OpenFile *open_file)
 	gtk_widget_grab_focus(vmaid->drawing);
 
 	/* ǤϤʤե뤬¸ߤˤ˲ä */
-	if (open_file!=NULL && history>0 && isfile(vmaid->file))
-		set_history(vmaid->file);
+	if (file_open!=NULL && history>0 && misc_isfile(vmaid->file))
+		file_set_history(vmaid->file);
 
 	gdk_threads_leave();
 
-	g_free(open_file);
+	g_free(file_open);
 	thread_delete(id);
 	return vmaid;
 }
@@ -528,9 +528,9 @@ static gboolean save_edit_file_callback(gint percent,gpointer user_data)
 
 
 /*	AVIե¸
-	save_file,Save
+	file_save,Save
 	      RET,TRUE:ｪλ,FALSE:顼									*/
-gboolean save_edit_file(SaveFile *save_file)
+gboolean file_save_edit(FileSave *file_save)
 {
 	int fd;
 	gboolean result=TRUE;
@@ -540,28 +540,28 @@ gboolean save_edit_file(SaveFile *save_file)
 	AviEdit *avi[3];
 
 	id=pthread_self();
-	thread_insert(id,2,save_file->file);
+	thread_insert(id,2,file_save->file);
 
-	switch (save_file->mode) {
+	switch (file_save->mode) {
 		case 2:
-			avi[j++]=save_file->avi[1];
+			avi[j++]=file_save->avi[1];
 		case 1:
 			break;
 		default:
 			for (i=0;i<2;i++)
-				if (save_file->avi[i]!=NULL)
-					avi[j++]=save_file->avi[i];
+				if (file_save->avi[i]!=NULL)
+					avi[j++]=file_save->avi[i];
 	}
 
-	if (save_file->mode==1) {
-		result=avi_save_bitmap(save_file->avi[0],save_file->file,
-				save_file->start,save_file->end,save_edit_file_callback,NULL);
+	if (file_save->mode==1) {
+		result=avi_save_bitmap(file_save->avi[0],file_save->file,
+				file_save->start,file_save->end,save_edit_file_callback,NULL);
 	} else {
 		avi[j++]=NULL;
-		if (save_file->mode!=3) {
-			result=avi_save(avi,save_file->file,save_edit_file_callback,NULL);
+		if (file_save->mode!=3) {
+			result=avi_save(avi,file_save->file,save_edit_file_callback,NULL);
 		} else if ((scenario=avi_to_scenario(avi,FALSE))!=NULL) {
-			if ((fd=open(save_file->file,O_CREAT|O_EXCL|O_WRONLY,
+			if ((fd=open(file_save->file,O_CREAT|O_EXCL|O_WRONLY,
 					S_IRUSR|S_IWUSR|S_IRGRP|S_IWGRP|S_IROTH|S_IWOTH))!=-1) {
 				length=strlen(scenario);
 				if (flock(fd,LOCK_EX)==-1 || write(fd,scenario,length)!=length)
@@ -575,11 +575,11 @@ gboolean save_edit_file(SaveFile *save_file)
 		}
 	}
 
-	g_free(save_file->file);
+	g_free(file_save->file);
 	for (i=0;i<2;i++)
-		if (save_file->avi[i]!=NULL)
-			avi_release(save_file->avi[i]);
-	g_free(save_file);
+		if (file_save->avi[i]!=NULL)
+			avi_release(file_save->avi[i]);
+	g_free(file_save);
 
 	if (!result)
 		while (thread_idling(id,-1));
