@@ -1,6 +1,6 @@
 /*
     Video maid
-    copyright (c) 1998-2002 Iwamoto,Kazuki http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,13 +20,13 @@
 #include <string.h>
 #include <gdk/gdkkeysyms.h>
 #include "argument.h"
-#include "avicore.h"
 #include "command.h"
 #include "file.h"
 #include "general.h"
-#include "other.h"
 #include "signal.h"
 #include "thread.h"
+#include "avicore/avicore.h"
+#include "misc/misc.h"
 #include <gdk/gdkrgb.h>
 
 
@@ -49,7 +49,7 @@ gboolean signal_timeout(gpointer data)
 		if (vmaid->top<=vmaid->cursor.frame
 									&& vmaid->cursor.frame<=vmaid->top+sx) {
 			rc.x=(vmaid->cursor.frame-vmaid->top+1)*vmaid->width+1;
-			rc.y=system_fontheight*2
+			rc.y=system_font_height*2
 								+(vmaid->avi[0]!=NULL && vmaid->cursor.stream>0
 															?vmaid->height:0);
 			rc.width=2;
@@ -115,7 +115,7 @@ gboolean signal_config(GtkWidget *widget,GdkEventConfigure *config,
 	if (vmaid->top>max-sx)
 		vmaid->top=MAX(max-sx,0);
 	draw_caret(vmaid,NULL);
-	set_scroll_bar(vmaid->hscroll,signal_value_changed_hscroll,vmaid,
+	misc_set_scroll_bar(vmaid->hscroll,signal_value_changed_hscroll,vmaid,
 														0,max,sx,vmaid->top);
 	return TRUE;
 }
@@ -131,13 +131,13 @@ static void signal_expose_text(GtkWidget *widget,GdkGC *gc,VmaidWindow *vmaid,
 						&& avi_is_keyframe(vmaid->avi[0],pos)?"%d*":"%d",pos);
 	if (gdk_string_width(system_font,text)<=vmaid->width)
 		gdk_draw_string(widget->window,system_font,gc,
-													x,system_fontascent,text);
+													x,system_font_ascent,text);
 	g_free(text);
 	t=(gint64)pos*vmaid->scale*1000/vmaid->rate;
 	text=g_strdup_printf("%02d:%02d:%02d",t/60000%100,t/1000%60,t/10%100);
 	if (gdk_string_width(system_font,text)<=vmaid->width)
 		gdk_draw_string(widget->window,system_font,gc,
-								x,y+system_fontascent+system_fontheight,text);
+							x,y+system_font_ascent+system_font_height,text);
 	g_free(text);
 }
 
@@ -291,10 +291,10 @@ gboolean signal_expose(GtkWidget *widget,GdkEventExpose *event,
 		gdk_color_alloc(gdk_colormap_get_system(),system_color+i);
 	gdk_gc_set_clip_rectangle(gc,&event->area);
 	/* ե졼֤ط */
-	if (system_fontheight*2-event->area.y>0) {
+	if (system_font_height*2-event->area.y>0) {
 		gdk_gc_set_foreground(gc,system_color+1);
 		gdk_draw_rectangle(widget->window,gc,TRUE,event->area.x,event->area.y,
-						event->area.width,system_fontheight*2-event->area.y);
+						event->area.width,system_font_height*2-event->area.y);
 	}
 	/* ե졼 */
 	sx=MAX((widget->allocation.width-4)/vmaid->width-2,1);
@@ -308,7 +308,7 @@ gboolean signal_expose(GtkWidget *widget,GdkEventExpose *event,
 		signal_expose_text(widget,gc,vmaid,i,rc0.x,0);
 	if (vmaid->top+sx<=frame)			/* 򳫻ϰ֤ΤȤ */
 		signal_expose_text(widget,gc,vmaid,frame,vmaid->width*(sx+1)+4,0);
-	rc0.y=system_fontheight*2;
+	rc0.y=system_font_height*2;
 	rc0.height=vmaid->height;
 	if (vmaid->avi[0]!=NULL) {
 		max=MIN(get_max_frame(vmaid,0),vmaid->top+sx-1);
@@ -418,7 +418,7 @@ gboolean signal_expose(GtkWidget *widget,GdkEventExpose *event,
 			rc0.height=MAX(vmaid->cursor.stream,vmaid->select.stream)-rc0.y+1;
 			if (vmaid->avi[0]==NULL)
 				rc0.y--;
-			rc0.y=rc0.y*vmaid->height+system_fontheight*2;
+			rc0.y=rc0.y*vmaid->height+system_font_height*2;
 			rc0.height*=vmaid->height;
 			if (gdk_rectangle_intersect(&event->area,&rc0,&rc1)) {
 				gdk_gc_set_foreground(gc,system_color+3);
@@ -435,7 +435,7 @@ gboolean signal_expose(GtkWidget *widget,GdkEventExpose *event,
 									&& vmaid->top<=vmaid->cursor.frame
 									&& vmaid->cursor.frame<=vmaid->top+sx) {
 		rc0.x=(vmaid->cursor.frame-vmaid->top+1)*vmaid->width+1;
-		rc0.y=system_fontheight*2
+		rc0.y=system_font_height*2
 			+(vmaid->avi[0]!=NULL && vmaid->cursor.stream>0?vmaid->height:0);
 		rc0.width=2;
 		rc0.height=vmaid->height;
@@ -482,7 +482,7 @@ gboolean signal_button_press(GtkWidget *widget,GdkEventButton *event,
 					vmaid->cursor.frame=max;
 				if (vmaid->avi[0]!=NULL && vmaid->avi[1]!=NULL)
 					vmaid->cursor.stream
-							=event->y<system_fontheight*2+vmaid->height?0:1;
+							=event->y<system_font_height*2+vmaid->height?0:1;
 				if (vmaid->select.stream>=0 && (!shift
 								|| vmaid->cursor.frame==vmaid->select.frame))
 					vmaid->select.stream=-1;/*  */
@@ -530,7 +530,8 @@ gboolean signal_button_press(GtkWidget *widget,GdkEventButton *event,
 				else if (vmaid->top>max-sx)
 					vmaid->top=MAX(max-sx,0);
 				if (vmaid->top!=top)
-					set_scroll_bar(vmaid->hscroll,signal_value_changed_hscroll,
+					misc_set_scroll_bar(vmaid->hscroll,
+												signal_value_changed_hscroll,
 													vmaid,0,max,sx,vmaid->top);
 				clear_sel(vmaid,&vmaid->cursor,&vmaid->select,top);
 			}
@@ -579,7 +580,7 @@ static gboolean signal_motion_notify_draw(VmaidWindow *vmaid,gint x,gint y,
 	else if (vmaid->cursor.frame>max)
 		vmaid->cursor.frame=max;
 	if (vmaid->avi[0]!=NULL && vmaid->avi[1]!=NULL)
-		vmaid->cursor.stream=ps.y<system_fontheight*2+vmaid->height?0:1;
+		vmaid->cursor.stream=ps.y<system_font_height*2+vmaid->height?0:1;
 	if (vmaid->cursor.frame==cursor.frame
 										&& vmaid->cursor.stream==cursor.stream)
 		return FALSE;/* Ѳʤ */
@@ -591,7 +592,7 @@ static gboolean signal_motion_notify_draw(VmaidWindow *vmaid,gint x,gint y,
 	if (vmaid->select.stream!=select.stream)
 		set_menu_bar(vmaid);
 	if (vmaid->top!=top)
-		set_scroll_bar(vmaid->hscroll,signal_value_changed_hscroll,vmaid,
+		misc_set_scroll_bar(vmaid->hscroll,signal_value_changed_hscroll,vmaid,
 														0,max,sx,vmaid->top);
 	clear_sel(vmaid,&cursor,&select,top);
 	draw_caret(vmaid,&cursor);
@@ -690,7 +691,8 @@ gboolean signal_key_press(GtkWidget *widget,GdkEventKey *event,
 				set_menu_bar(vmaid);/* ˥塼 */
 			}
 			if (vmaid->top!=top)
-				set_scroll_bar(vmaid->hscroll,signal_value_changed_hscroll,
+				misc_set_scroll_bar(vmaid->hscroll,
+												signal_value_changed_hscroll,
 													vmaid,0,max,sx,vmaid->top);
 			clear_sel(vmaid,&cursor,&select,top);
 			draw_caret(vmaid,&cursor);
@@ -799,7 +801,8 @@ gboolean signal_key_press(GtkWidget *widget,GdkEventKey *event,
 							|| (vmaid->select.stream>=0 && select.stream<0))
 				set_menu_bar(vmaid);
 			if (vmaid->top!=top)
-				set_scroll_bar(vmaid->hscroll,signal_value_changed_hscroll,
+				misc_set_scroll_bar(vmaid->hscroll,
+												signal_value_changed_hscroll,
 													vmaid,0,max,sx,vmaid->top);
 			clear_sel(vmaid,&cursor,&select,top);
 			draw_caret(vmaid,&cursor);
@@ -827,7 +830,8 @@ gboolean signal_key_press(GtkWidget *widget,GdkEventKey *event,
 			/* ˥塼 */
 			set_menu_bar(vmaid);
 			if (vmaid->top!=top)
-				set_scroll_bar(vmaid->hscroll,signal_value_changed_hscroll,
+				misc_set_scroll_bar(vmaid->hscroll,
+												signal_value_changed_hscroll,
 							vmaid,0,get_max_frame(vmaid,-1)+1,sx,vmaid->top);
 			clear_sel(vmaid,&cursor,&select,top);
 			draw_caret(vmaid,&cursor);
@@ -875,7 +879,8 @@ gboolean signal_key_press(GtkWidget *widget,GdkEventKey *event,
 			else if (vmaid->top<vmaid->cursor.frame-sx)
 				vmaid->top=MAX(vmaid->cursor.frame-sx,0);
 			if (vmaid->top!=top)
-				set_scroll_bar(vmaid->hscroll,signal_value_changed_hscroll,
+				misc_set_scroll_bar(vmaid->hscroll,
+												signal_value_changed_hscroll,
 							vmaid,0,get_max_frame(vmaid,-1)+1,sx,vmaid->top);
 			clear_sel(vmaid,&vmaid->cursor,&vmaid->select,top);
 			gtk_widget_set_sensitive(gtk_item_factory_get_widget(
@@ -930,7 +935,7 @@ void signal_destroy_draw(GtkWidget *widget,VmaidWindow *vmaid)
 	GtkWidget *sub_menu;
 
 	/* ե̾Ĵ٤ */
-	delete_edit_file(vmaid->file);
+	file_delete_edit(vmaid->file);
 	/* ɥ˥塼 */
 	sub_menu=gtk_item_factory_get_widget(item_factory_menu,"<main>/Window");
 	gtk_container_remove(GTK_CONTAINER(sub_menu),vmaid->menu_item);
@@ -981,17 +986,17 @@ void signal_style_set(GtkWidget *widget,GtkStyle *style,gpointer user_data)
 	for (i=0;i<256;i++) {
 		gdk_text_extents(system_font,(gchar *)&i,1,
 												NULL,NULL,NULL,&ascent,NULL);
-		if (system_fontascent<ascent)
-			system_fontascent=ascent;
+		if (system_font_ascent<ascent)
+			system_font_ascent=ascent;
 		height=gdk_char_height(system_font,i);
-		if (system_fontheight<height)
-			system_fontheight=height;
+		if (system_font_height<height)
+			system_font_height=height;
 	}
 	glist=gtk_container_children(GTK_CONTAINER(notebook));
 	for (i=g_list_length(glist)-1;i>=0;i--) {
 		vmaid=gtk_object_get_user_data(GTK_OBJECT(g_list_nth_data(glist,i)));
 		gtk_widget_set_usize(vmaid->drawing,vmaid->width*3+4,
-								system_fontheight*2+((vmaid->avi[0]!=NULL?1:0)
+								system_font_height*2+((vmaid->avi[0]!=NULL?1:0)
 									+(vmaid->avi[1]!=NULL?1:0))*vmaid->height);
 		gtk_container_queue_resize(GTK_CONTAINER(window));
 		gtk_widget_draw(vmaid->drawing,NULL);
@@ -1017,12 +1022,12 @@ void signal_activate_menu_window(GtkWidget *widget,GtkWidget *child)
 void signal_activate_menu_history(GtkWidget *widget,gchar *file)
 {
 	pthread_t id;
-	OpenFile *open_file;
+	FileOpen *file_open;
 
-	open_file=g_malloc(sizeof(OpenFile));
-	open_file->file=g_strdup(file);
-	open_file->merge=file_merge;
-	pthread_create(&id,NULL,(void *)open_edit_file,open_file);
+	file_open=g_malloc(sizeof(FileOpen));
+	file_open->file=g_strdup(file);
+	file_open->merge=file_merge;
+	pthread_create(&id,NULL,(void *)file_open_edit,file_open);
 	pthread_detach(id);
 }
 
@@ -1105,15 +1110,15 @@ void signal_drag_data_received(GtkWidget *widget,GdkDragContext *context,
 	gchar **files;
 	gint i;
 	pthread_t id;
-	OpenFile *open_file;
+	FileOpen *file_open;
 
 	files=g_strsplit(selection_data->data,"\r\n",G_MAXINT);
 	for (i=0;files[i]!=NULL;i++)
 		if (strncmp(files[i],"file:",5)==0) {
-			open_file=g_malloc(sizeof(OpenFile));
-			open_file->file=g_strdup(files[i]+5);
-			open_file->merge=file_merge;
-			pthread_create(&id,NULL,(void *)open_edit_file,open_file);
+			file_open=g_malloc(sizeof(FileOpen));
+			file_open->file=g_strdup(files[i]+5);
+			file_open->merge=file_merge;
+			pthread_create(&id,NULL,(void *)file_open_edit,file_open);
 			pthread_detach(id);
 		}
 	g_strfreev(files);
@@ -1167,7 +1172,7 @@ void signal_selection_received(GtkWidget *widget,GtkSelectionData *data,
 	gint i,count,max,sx;
 	pthread_t id;
 	AviEdit **avi;
-	OpenFile *open_file;
+	FileOpen *file_open;
 	GdkAtom *atoms;
 	VmaidWindow *vmaid;
 	VmaidHistory *d;
@@ -1201,7 +1206,7 @@ void signal_selection_received(GtkWidget *widget,GtkSelectionData *data,
 							result=FALSE;
 					}
 					if (!result) {
-						message_box("Video maid",_("AVI Clone Error"),0,
+						misc_message_box("Video maid",_("AVI Clone Error"),0,
 																_("OK"),NULL);
 						for (i=0;i<2;i++)
 							if (d->avi[i]!=NULL)
@@ -1263,7 +1268,7 @@ void signal_selection_received(GtkWidget *widget,GtkSelectionData *data,
 					}
 				g_free(avi);
 				if (!result || (!paste[0] && !paste[1])) {
-					message_box("Video maid",_("AVI Paste Error"),0,
+					misc_message_box("Video maid",_("AVI Paste Error"),0,
 																_("OK"),NULL);
 					for (i=0;i<2;i++)
 						if (vmaid->avi[i]!=NULL)
@@ -1294,12 +1299,13 @@ void signal_selection_received(GtkWidget *widget,GtkSelectionData *data,
 				/* ˥塼,ơȥ,ҥɥ */
 				set_menu_bar(vmaid);
 				gtk_widget_set_usize(vmaid->drawing,vmaid->width*3+4,
-								system_fontheight*2+((vmaid->avi[0]!=NULL?1:0)
+								system_font_height*2+((vmaid->avi[0]!=NULL?1:0)
 									+(vmaid->avi[1]!=NULL?1:0))*vmaid->height);
 				gtk_container_queue_resize(GTK_CONTAINER(window));
 				gtk_widget_draw(vmaid->drawing,NULL);
 				draw_caret(vmaid,NULL);
-				set_scroll_bar(vmaid->hscroll,signal_value_changed_hscroll,
+				misc_set_scroll_bar(vmaid->hscroll,
+												signal_value_changed_hscroll,
 													vmaid,0,max,sx,vmaid->top);
 				vmaid->edit=TRUE;
 			}
@@ -1307,17 +1313,17 @@ void signal_selection_received(GtkWidget *widget,GtkSelectionData *data,
 	} else if (data->selection==atom_videomaid0) {
 		/* ץ̿ */
 		instance=MAX(data->length,0);
-	} else if (data->selection==atom_videomaid1) {
+	} else if (data->selection==atom_videomaid1 && data->length>0) {
 		/* ץ̿ */
 		/* ޥɥ饤β */
 		argv=g_strsplit(data->data,"\n",G_MAXINT);
 		arg_files=arg_analyse(argv,FALSE);
 		for (i=0;argv[i]!=NULL;i++)
 			if (arg_files[i]) {
-				open_file=g_malloc(sizeof(OpenFile));
-				open_file->file=g_strdup(argv[i]);
-				open_file->merge=file_merge;
-				pthread_create(&id,NULL,(void *)open_edit_file,open_file);
+				file_open=g_malloc(sizeof(FileOpen));
+				file_open->file=g_strdup(argv[i]);
+				file_open->merge=file_merge;
+				pthread_create(&id,NULL,(void *)file_open_edit,file_open);
 				pthread_detach(id);
 			}
 		g_free(arg_files);
@@ -1356,11 +1362,11 @@ void signal_destroy_window(GtkWidget *widget,gpointer user_data)
 	GList *glist;
 	GtkWidget *sub_menu;
 
-	memset(history_file,0,sizeof(gchar *)*10);
+	memset(history_files,0,sizeof(gchar *)*10);
 	sub_menu=gtk_item_factory_get_widget(item_factory_menu,"<main>/File");
 	glist=gtk_container_children(GTK_CONTAINER(sub_menu));
 	for (i=0;i<(gint)g_list_length(glist)-MENUFILE-1;i++)
-		history_file[i]=g_strdup(gtk_object_get_user_data(
+		history_files[i]=g_strdup(gtk_object_get_user_data(
 							GTK_OBJECT(g_list_nth_data(glist,i+MENUFILE-1))));
 	g_list_free(glist);
 	gtk_main_quit();
