@@ -1,6 +1,6 @@
 /*
     Video maid
-    copyright (c) 1998-2002 Iwamoto,Kazuki http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -31,7 +31,7 @@
 	    height,⤵
 	 def_width,ǥեȤ
 	def_height,ǥեȤι⤵												*/
-void set_scale(gint view,gint *width,gint *height,
+void size_set_scale(const gint view,gint *width,gint *height,
 									const gint def_width,const gint def_height)
 {
 	switch (def_width<=0 || def_height<=0?view|4:view) {
@@ -107,7 +107,7 @@ static void size_dialog_clicked_button(GtkWidget *widget,SizeDialog *size)
 	gint width,height;
 
 	def_view=(gint)gtk_object_get_user_data(GTK_OBJECT(widget));
-	set_scale(def_view,&width,&height,size->def_width,size->def_height);
+	size_set_scale(def_view,&width,&height,size->def_width,size->def_height);
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(spin0),width);
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(spin1),height);
 }
