@@ -1,6 +1,6 @@
 /*
     Video maid
-    copyright (c) 1998-2002 Iwamoto,Kazuki http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,23 +23,23 @@
 #include "vmaid.h"
 
 
-typedef struct {
+typedef struct SizeDialog_Tag {
 	gboolean ratio;			/* TRUE:Ψݻʤ,FALSE:Ψݻ */
 	gint view,width,height,def_width,def_height;
 } SizeDialog;
 
 
-gboolean size_dialog(SizeDialog *size);
-
-
 /*	ե졼ॵ
 	      view,
 	     width,
 	    height,⤵
 	 def_width,ǥեȤ
 	def_height,ǥեȤι⤵												*/
-void set_scale(gint view,gint *width,gint *height,
+void size_set_scale(const gint view,gint *width,gint *height,
 								const gint def_width,const gint def_height);
 
 
+gboolean size_dialog(SizeDialog *size);
+
+
 #endif
