@@ -1,6 +1,6 @@
 /*
     Video maid
-    copyright (c) 1998-2002 Iwamoto,Kazuki http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -34,10 +34,10 @@ static volatile gint critical=FALSE;
 	mode,⡼(0:λ,1:,2:¸,3:ե졼,4:ȿž)
 	file,ե̾
 	 RET,TRUE:ｪλ,FALSE:顼											*/
-gboolean thread_insert(pthread_t id,gint mode,gchar *file)
+gboolean thread_insert(pthread_t id,const gint mode,const gchar *file)
 {
 	gchar *text[4];
-	gchar *mode_name[]={N_("Exit"),N_("Open"),N_("Save"),N_("Change Frames"),
+	gchar *name[]={N_("Exit"),N_("Open"),N_("Save"),N_("Change Frames"),
 																N_("Reverse")};
 	time_t tm;
 	ThreadList *tl;
@@ -48,9 +48,9 @@ gboolean thread_insert(pthread_t id,gint mode,gchar *file)
 	tl->userbreak=TRUE;
 	tl->id=id;
 	/* ⡼ */
-	text[0]=mode_name[mode];
+	text[0]=name[mode];
 	/* ե̾ */
-	text[1]=file!=NULL?file:"";
+	text[1]=file!=NULL?(gchar *)file:"";
 	/*  */
 	tm=time(NULL);
 	text[2]=ctime(&tm);
@@ -74,7 +74,7 @@ gboolean thread_insert(pthread_t id,gint mode,gchar *file)
 	     id,åID
 	percent,ʹԾ
 	    RET,TRUE:³,FALSE:											*/
-gboolean thread_idling(pthread_t id,gint percent)
+gboolean thread_idling(pthread_t id,const gint percent)
 {
 	gchar *text;
 	gint i;
@@ -142,7 +142,7 @@ gboolean thread_delete(pthread_t id)
 /*	ꥹȤ
 	all,TRUE:٤ƤΥå,FALSE:򤵤줿åɤΤ
 	RET,TRUE:ｪλ,FALSE:顼											*/
-gboolean thread_break(gboolean all)
+gboolean thread_break(const gboolean all)
 {
 	gint i;
 	ThreadList *tl;
