@@ -1,6 +1,6 @@
 /*
     Video maid
-    copyright (c) 1998-2002 Iwamoto,Kazuki http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -25,7 +25,14 @@
 #include "vmaid.h"
 
 
-typedef struct {
+#define THREAD_MODE_EXIT 0
+#define THREAD_MODE_OPEN 1
+#define THREAD_MODE_SAVE 2
+#define THREAD_MODE_FRAME 3
+#define THREAD_MODE_REVERSE 4
+
+
+typedef struct ThreadList_Tag {
 	gboolean userbreak;	/* TRUE:³,FALSE:׵ */
 	gint mode;			/* 0:λ,1:,2:¸,3:ե졼,4:ȿž */
 	gint percent;		/* ʹԾ(0...100) */
@@ -43,14 +50,14 @@ typedef struct {
 	mode,⡼(0:λ,1:,2:¸,3:ե졼,4:ȿž)
 	file,ե̾
 	 RET,TRUE:ｪλ,FALSE:顼											*/
-gboolean thread_insert(pthread_t id,gint mode,gchar *file);
+gboolean thread_insert(pthread_t id,const gint mode,const gchar *file);
 
 
 /*	ꥹȤ򹹿
 	     id,åID
 	percent,ʹԾ
 	    RET,TRUE:³,FALSE:											*/
-gboolean thread_idling(pthread_t id,gint percent);
+gboolean thread_idling(pthread_t id,const gint percent);
 
 
 /*	ꥹȤ
@@ -62,7 +69,7 @@ gboolean thread_delete(pthread_t id);
 /*	ꥹȤ
 	all,TRUE:٤ƤΥå,FALSE:򤵤줿åɤΤ
 	RET,TRUE:ｪλ,FALSE:顼											*/
-gboolean thread_break(gboolean all);
+gboolean thread_break(const gboolean all);
 
 
 /*	ץνλ(Ωå)											*/
