@@ -1,6 +1,6 @@
 /*
     Video maid
-    copyright (c) 1998-2002 Iwamoto,Kazuki http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -298,7 +298,7 @@ static gchar *tb_redo_xpm[]={
 "                "};
 
 
-ToolbarItem toolbar_items[]={
+ToolBar toolbar_items[]={
 /*  0 */ {N_("New"),       tb_new_xpm,    command_new,     NULL,NULL},
 /*  1 */ {N_("Open"),      tb_open_xpm,   command_open,    NULL,NULL},
 /*  2 */ {N_("Save As"),   tb_save_xpm,   command_save,    NULL,NULL},
