@@ -1,6 +1,6 @@
 /*
     Video maid
-    copyright (c) 1998-2002 Iwamoto,Kazuki http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,16 +23,16 @@
 #include "vmaid.h"
 
 
-typedef struct {
+typedef struct ToolBar_Tag {
 	gchar *name;
 	gchar **xpm;
 	GtkSignalFunc callback;
 	gpointer user_data;
 	GtkWidget *item;
-} ToolbarItem;
+} ToolBar;
 
 
-extern ToolbarItem toolbar_items[];
+extern ToolBar toolbar_items[];
 
 
 #endif
