@@ -1,6 +1,6 @@
 /*
     Video maid
-    copyright (c) 1998-2002 Iwamoto,Kazuki http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -27,11 +27,11 @@
 #include "conf.h"
 #include "file.h"
 #include "general.h"
-#include "other.h"
-#include "profile.h"
 #include "signal.h"
 #include "toolbar.h"
 #include "version.h"
+#include "misc/misc.h"
+#include "misc/profile.h"
 #include <gdk/gdkrgb.h>
 
 
@@ -40,7 +40,7 @@ gboolean newfile=FALSE;				/* TRUE:ե,FALSE:ʤ */
 gboolean second=FALSE;				/* TRUE:,FALSE:¸ */
 gboolean default_ratio=FALSE;		/* TRUE:/Ψݻʤ */
 gboolean file_merge=FALSE;			/* TRUE:Ϣ,FALSE:ñ */
-gchar *history_file[10];			/* ե */
+gchar *history_files[10];			/* ե */
 gchar *open_path=NULL;				/* Υѥ */
 gchar *save_path=NULL;				/* ̾դ¸Υѥ */
 gchar *clipboard_scenario=NULL;		/* åץܡɤΥƥ */
@@ -66,8 +66,8 @@ GtkPositionType n_pos=GTK_POS_TOP;	/* Ρȥ֥åΰ */
 GtkItemFactory *item_factory_menu;	/* ˥塼 */
 GtkItemFactory *item_factory_popup;	/* ݥåץå */
 GdkFont *system_font=NULL;
-gint system_fontheight;				/* եȤι⤵ */
-gint system_fontascent;				/* եȤΥȤι⤵ */
+gint system_font_height;			/* եȤι⤵ */
+gint system_font_ascent;				/* եȤΥȤι⤵ */
 GdkColor system_color[4]={	{0,0x0000,0x0000,0x0000},{0,0xffff,0xffff,0xffff},
 							{0,0xffff,0xffff,0xffff},{0,0x0000,0x0000,0x8000}};
 GtkTargetEntry targets_vmaid[]={	/* Video maid󶡲ǽʥ쥯 */
@@ -93,8 +93,8 @@ int main(int argc,char *argv[])
 	gchar *arg,*key;
 	gint i,count=0,ascent,height,leng,length=0;
 	pthread_t id;
-	OpenFile *open_file;
-	PROFILE *profile;
+	FileOpen *file_open;
+	Profile *profile;
 	GdkBitmap *mask;
 	GdkPixmap *pixmap;
 	GtkAccelGroup *accel_group;
@@ -177,7 +177,7 @@ int main(int argc,char *argv[])
 
 	def_width=gdk_screen_width()*2/3;
 	def_height=gdk_screen_height()*2/3;
-	memset(history_file,0,sizeof(gchar *)*10);
+	memset(history_files,0,sizeof(gchar *)*10);
 	/* 쥸ȥ꤫ɤ߽Ф */
 	if ((profile=profile_open(".vmaid"))!=NULL) {
 		if (!profile_get_value(profile,"vmaid","history",
@@ -217,13 +217,13 @@ int main(int argc,char *argv[])
 		/* ե */
 		for (i=0;i<history;i++) {
 			key=g_strdup_printf("history%d",i);
-			history_file[i]=profile_get_string(profile,"vmaid",key);
+			history_files[i]=profile_get_string(profile,"vmaid",key);
 			g_free(key);
-			if (history_file[i]==NULL)
+			if (history_files[i]==NULL)
 				break;
-			if (*history_file[i]=='\0') {
-				g_free(history_file[i]);
-				history_file[i]=NULL;
+			if (*history_files[i]=='\0') {
+				g_free(history_files[i]);
+				history_files[i]=NULL;
 				break;
 			}
 		}
@@ -345,13 +345,13 @@ int main(int argc,char *argv[])
 	gtk_container_add(GTK_CONTAINER(window),vbox);
 	/* ե */
 	sub_menu=gtk_item_factory_get_widget(item_factory_menu,"<main>/File");
-	for (i=0;i<history && history_file[i]!=NULL;i++) {
-		menu_item=gtk_menu_item_new_with_label(history_file[i]);
+	for (i=0;i<history && history_files[i]!=NULL;i++) {
+		menu_item=gtk_menu_item_new_with_label(history_files[i]);
 		gtk_signal_connect(GTK_OBJECT(menu_item),"activate",
-				GTK_SIGNAL_FUNC(signal_activate_menu_history),history_file[i]);
+			GTK_SIGNAL_FUNC(signal_activate_menu_history),history_files[i]);
 		gtk_signal_connect(GTK_OBJECT(menu_item),"destroy",
-				GTK_SIGNAL_FUNC(signal_destroy_menu_history),history_file[i]);
-		gtk_object_set_user_data(GTK_OBJECT(menu_item),history_file[i]);
+				GTK_SIGNAL_FUNC(signal_destroy_menu_history),history_files[i]);
+		gtk_object_set_user_data(GTK_OBJECT(menu_item),history_files[i]);
 		gtk_menu_insert(GTK_MENU(sub_menu),menu_item,i+MENUFILE-1);
 	}
 	if (i>0)
@@ -366,7 +366,7 @@ int main(int argc,char *argv[])
 	if (!second) {
 		for (i=1;i<argc;i++) {
 			if (arg_files[i-1]) {
-				arg=get_full_path(argv[i]);
+				arg=misc_get_full_path(argv[i]);
 				leng=strlen(arg)*sizeof(gchar);
 				arg_text=g_realloc(arg_text,length+leng+sizeof(gchar));
 				memcpy(arg_text+length,arg,leng);
@@ -429,26 +429,26 @@ int main(int argc,char *argv[])
 	for (i=0;i<256;i++) {
 		gdk_text_extents(system_font,(gchar *)&i,1,
 												NULL,NULL,NULL,&ascent,NULL);
-		if (system_fontascent<ascent)
-			system_fontascent=ascent;
+		if (system_font_ascent<ascent)
+			system_font_ascent=ascent;
 		height=gdk_char_height(system_font,i);
-		if (system_fontheight<height)
-			system_fontheight=height;
+		if (system_font_height<height)
+			system_font_height=height;
 	}
 
 	/* ɥ */
 	for (i=1;i<argc;i++)
 		if (arg_files[i-1]) {
-			open_file=g_malloc(sizeof(OpenFile));
-			open_file->file=g_strdup(argv[i]);
-			open_file->merge=file_merge;
-			pthread_create(&id,NULL,(void *)open_edit_file,open_file);
+			file_open=g_malloc(sizeof(FileOpen));
+			file_open->file=g_strdup(argv[i]);
+			file_open->merge=file_merge;
+			pthread_create(&id,NULL,(void *)file_open_edit,file_open);
 			pthread_detach(id);
 			count++;
 		}
 	g_free(arg_files);
 	if (newfile && count<=0) {
-		pthread_create(&id,NULL,(void *)open_edit_file,NULL);
+		pthread_create(&id,NULL,(void *)file_open_edit,NULL);
 		pthread_detach(id);
 	}
 
@@ -490,10 +490,10 @@ int main(int argc,char *argv[])
 										(strlen(save_path)+1)*sizeof(gchar),
 													PROFILE_VALUE_TYPE_STRING);
 		/* ե */
-		for (i=0;i<history && history_file[i]!=NULL;i++) {
+		for (i=0;i<history && history_files[i]!=NULL;i++) {
 			key=g_strdup_printf("history%d",i);
-			profile_set_value(profile,"vmaid",key,(gpointer)history_file[i],
-									(strlen(history_file[i])+1)*sizeof(gchar),
+			profile_set_value(profile,"vmaid",key,(gpointer)history_files[i],
+									(strlen(history_files[i])+1)*sizeof(gchar),
 													PROFILE_VALUE_TYPE_STRING);
 			g_free(key);
 		}
@@ -510,6 +510,6 @@ int main(int argc,char *argv[])
 	g_free(open_path);
 	g_free(save_path);
 	for (i=0;i<history;i++)
-		g_free(history_file[i]);
+		g_free(history_files[i]);
 	return 0;
 }
