@@ -1,6 +1,6 @@
 /*
     Video maid
-    copyright (c) 1998-2002 Iwamoto,Kazuki http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -26,23 +26,23 @@
 
 
 #include <gtk/gtk.h>
-#include "avicore.h"
+#include "avicore/avicore.h"
 #include "intl.h"
 
 
 #define MENUFILE 9
 
 
-typedef struct {
+typedef struct VmaidCursor_Tag {
 	gint stream;				/* ȥ꡼ΰ(0,1) */
 	gint frame;					/* ߤΰ(0...) */
 } VmaidCursor;
-typedef struct VmaidDoing_Tag {
+typedef struct VmaidHistory_Tag {
 	AviEdit *avi[2];			/* AVIԽ */
 	VmaidCursor cursor,select;
-	struct VmaidDoing_Tag *next;
+	struct VmaidHistory_Tag *next;
 } VmaidHistory;
-typedef struct {
+typedef struct VmaidWindow_Tag {
 	gboolean edit;				/* TRUE:ԽѤ,FALSE:̤Խ */
 	gchar *file;				/* ե̾ */
 	gint same;					/* -1:ʣʤ,0:ֹ */
@@ -74,7 +74,7 @@ extern gboolean newfile;				/* TRUE:ե,FALSE:ʤ */
 extern gboolean second;					/* TRUE:,FALSE:¸ */
 extern gboolean default_ratio;			/* TRUE:/Ψݻʤ */
 extern gboolean file_merge;				/* TRUE:Ϣ,FALSE:ñ */
-extern gchar *history_file[10];			/* ե */
+extern gchar *history_files[10];		/* ե */
 extern gchar *open_path;				/* Υѥ */
 extern gchar *save_path;				/* ̾դ¸Υѥ */
 extern gchar *clipboard_scenario;		/* åץܡɤΥƥ */
@@ -100,8 +100,8 @@ extern GtkPositionType n_pos;			/* Ρȥ֥åΰ */
 extern GtkItemFactory *item_factory_menu;	/* ˥塼 */
 extern GtkItemFactory *item_factory_popup;	/* ݥåץå */
 extern GdkFont *system_font;			/* ե */
-extern gint system_fontheight;			/* եȤι⤵ */
-extern gint system_fontascent;			/* եȤΥȤι⤵ */
+extern gint system_font_height;			/* եȤι⤵ */
+extern gint system_font_ascent;			/* եȤΥȤι⤵ */
 extern GdkColor system_color[4];
 extern GtkTargetEntry targets[1];	/* Video maid󶡲ǽʥ쥯 */
 
